@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
 our $DATE = '2015-08-09'; # DATE
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1347,7 +1347,8 @@ sub run {
             # [ux] if there is an error and no result, we still show the error
             # message from res[0] & res[1]. otherwise, user might be confused
             # because there is no error message
-            $r->{fres} = "ERROR $r->{res}[0]: $r->{res}[1]";
+            $r->{fres} = "ERROR $r->{res}[0]: $r->{res}[1]" .
+                ($r->{res}[1] =~ /\R\z/ ? "" : "\n");
         } else {
             $r->{fres} = $r->{res}[2] // '';
         }
@@ -1399,7 +1400,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.25 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-08-09.
+This document describes version 1.26 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-08-09.
 
 =head1 DESCRIPTION
 
